﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const util_1 = require("util");
const base_1 = require("../util/base");
const sponsor_1 = require("../util/sponsor");
class Config extends base_1.BaseKitaCommand {
    static description = 'Prints the full resolved configuration file';
    static examples = [
        {
            command: '<%= config.bin %> <%= command.id %> -c kita.config.js',
            description: 'Builds your backend with a custom config file.'
        }
    ];
    static flags = {
        raw: core_1.Flags.boolean({
            char: 'r',
            description: 'Prints a JSON string instead of a pretty printed object.',
            default: false,
            allowNo: true
        })
    };
    async run() {
        (0, sponsor_1.printSponsor)(this);
        const { flags } = await this.parse(Config);
        const { config, compilerOptions } = this.parseConfig(flags, undefined, false);
        //@ts-expect-error - Just to allow the compilerOptions to be printed
        config.compilerOptions = compilerOptions;
        //@ts-expect-error - Just to allow the compilerOptions to be pretty printed
        compilerOptions.rootNames = undefined;
        if (flags.raw || !process.stdout.isTTY) {
            this.log(JSON.stringify(config, null, 2));
        }
        else {
            this.log((0, util_1.inspect)(config, {
                colors: true,
                depth: Infinity,
                maxArrayLength: Infinity,
                maxStringLength: Infinity
            }));
        }
    }
}
exports.default = Config;
//# sourceMappingURL=config.js.map