﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const generator_1 = require("@kitajs/generator");
const parser_1 = require("@kitajs/parser");
const core_1 = require("@oclif/core");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const base_1 = require("../util/base");
const sponsor_1 = require("../util/sponsor");
const build_1 = tslib_1.__importDefault(require("./build"));
class Watch extends base_1.BaseKitaCommand {
    static description = 'Watch for changes in your source code and rebuilds the runtime.';
    static examples = [
        {
            command: '<%= config.bin %> <%= command.id %> -c kita.config.js',
            description: 'Watches your source with a custom config file.'
        },
        {
            command: '<%= config.bin %> <%= command.id %> -d',
            description: 'Watches your source and only emits errors.'
        }
    ];
    static flags = {
        ...build_1.default.flags,
        ignore: core_1.Flags.directory({
            description: 'Comma separated directories to ignore when watching for changes.',
            multiple: true,
            delimiter: ',',
            char: 'i',
            name: 'ignore',
            exists: true,
            helpGroup: 'watch'
        })
    };
    async run() {
        (0, sponsor_1.printSponsor)(this);
        const { flags } = await this.parse(Watch);
        const { config, compilerOptions } = this.parseConfig(flags, {
            declaration: flags.dts,
            watchIgnore: flags.ignore
        });
        await this.prepareFirstRun(config, compilerOptions);
        core_1.ux.action.start('Warming up', '', {
            stdout: true,
            style: 'clock'
        });
        const formatter = flags['dry-run'] ? undefined : new generator_1.KitaFormatter(config);
        const parser = parser_1.KitaParser.createWatcher(config, compilerOptions, 
        // Dry runs should not generate any files
        formatter);
        core_1.ux.action.stop((0, chalk_1.default) `{cyan Ready to build!}`);
        parser.onError = (err) => this.logToStderr(String(err));
        parser.onChange = async (parser) => {
            await this.runParser(parser, formatter, flags.reset, config);
            if (parser.getRouteCount() === 0) {
                this.warn((0, chalk_1.default) `{yellow No routes were found!}`);
            }
            // This newline is important to avoid mixing the output with the
            // previous parser output
            this.log('');
        };
    }
}
exports.default = Watch;
//# sourceMappingURL=watch.js.map