﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readConfig = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@kitajs/common");
const core_1 = require("@oclif/core");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const deepmerge_1 = tslib_1.__importDefault(require("deepmerge"));
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
function readConfig(root, error, configPath, extension, useUx = true) {
    // Tries to lookup for a default config file
    const defaultConfigPath = path_1.default.resolve(root, 'kita.config.js');
    if (configPath) {
        configPath = path_1.default.resolve(root, configPath);
    }
    else if (fs_1.default.existsSync(defaultConfigPath)) {
        configPath = defaultConfigPath;
    }
    if (!configPath) {
        return (0, common_1.parseConfig)(extension ?? {}, root);
    }
    if (useUx) {
        core_1.ux.action.start('Reading config', '', { stdout: true, style: 'clock' });
    }
    const exists = fs_1.default.existsSync(configPath);
    if (!exists) {
        error(`Config file does not exist: ${configPath}`);
    }
    const cfg = require(configPath);
    if (typeof cfg !== 'object') {
        error('Config file must export an object.');
    }
    const config = 
    // ESM Module support
    (0, common_1.parseConfig)((0, deepmerge_1.default)(extension ?? {}, typeof cfg.default === 'object' ? cfg.default : cfg, {
        arrayMerge: (_, source) => source
    }), root);
    if (useUx) {
        core_1.ux.action.stop(chalk_1.default.cyan(`.${path_1.default.sep}${path_1.default.relative(root, configPath)}`));
    }
    // @ts-expect-error - internal property
    config.extends = configPath;
    return config;
}
exports.readConfig = readConfig;
//# sourceMappingURL=config.js.map