﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatStatus = exports.formatDiagnostic = void 0;
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const typescript_1 = tslib_1.__importDefault(require("typescript"));
function formatDiagnostic(diagnostics) {
    const formatter = process.stdout.isTTY ? typescript_1.default.formatDiagnosticsWithColorAndContext : typescript_1.default.formatDiagnostics;
    return ('\n' +
        formatter(diagnostics, {
            getCanonicalFileName(fileName) {
                return fileName;
            },
            getCurrentDirectory() {
                return process.cwd();
            },
            getNewLine() {
                return '\n';
            }
        }));
}
exports.formatDiagnostic = formatDiagnostic;
function formatStatus(collector, diagnostics) {
    const routes = collector.getRoutes();
    const schemas = collector.getSchemas();
    const providers = collector.getProviderCount();
    const routesText = `${routes.length ? chalk_1.default.green(routes.length) : chalk_1.default.red(routes.length)} routes`;
    const schemasText = `${schemas.length ? chalk_1.default.green(schemas.length) : chalk_1.default.yellow(schemas.length)} schemas`;
    const providersText = `${providers ? chalk_1.default.green(providers) : chalk_1.default.yellow(providers)} providers`;
    const errorsText = `${diagnostics.length ? chalk_1.default.red(diagnostics.length) : chalk_1.default.green(diagnostics.length)} errors`;
    return `${routesText} / ${schemasText} / ${providersText} | ${errorsText}`;
}
exports.formatStatus = formatStatus;
//# sourceMappingURL=diagnostics.js.map